@@ -20,6 +20,10 @@ class Drawer:
 
     def __init__(self, p):
         self.poster = p
+        self.year_size = 200 * 4.0 / 80.0
+        self.year_style = f"font-size:{self.year_size}px; font-family:Arial;"
+        self.year_length_style = f"font-size:{110 * 3.0 / 80.0}px; font-family:Arial;"
+        self.month_names_style = "font-size:2.5px; font-family:Arial"
 
     @property
     def type_color_dict(self):
@@ -136,107 +140,116 @@ class Drawer:
                 rect = self.__add_animation(rect, key_times, animate_index)
             yield rect
 
-    def draw(self, dr, offset):
-        if self.poster.tracks is None:
-            raise BaseDrawError("No tracks to draw")
-        year_size = 200 * 4.0 / 80.0
-        year_style = f"font-size:{year_size}px; font-family:{self.poster.font};"
-        year_length_style = (
-            f"font-size:{110 * 3.0 / 80.0}px; font-family:{self.poster.font};"
+    def _draw_one_calendar(self, dr, year, offset, _type=None):
+        start_date_weekday, _ = calendar.monthrange(year, 1)
+        github_rect_first_day = datetime.date(year, 1, 1)
+        # Github profile the first day start from the last Monday of the last year
+        # or the first Monday of this year.
+        # It depands on if the first day of this year is Monday or not.
+        github_rect_day = github_rect_first_day + datetime.timedelta(
+            -start_date_weekday
         )
-        month_names_style = f"font-size:2.5px; font-family:{self.poster.font}"
-        total_sum_year_dict = self.poster.total_sum_year_dict
-        self.poster.years.sort()
-        year_count = len(self.poster.years)
-        for year in range(self.poster.years[0], self.poster.years[-1] + 1)[::-1]:
-            start_date_weekday, _ = calendar.monthrange(year, 1)
-            github_rect_first_day = datetime.date(year, 1, 1)
-            # Github profile the first day start from the last Monday of the last year
-            # or the first Monday of this year.
-            # It depands on if the first day of this year is Monday or not.
-            github_rect_day = github_rect_first_day + datetime.timedelta(
-                -start_date_weekday
+        year_length = self.poster.total_sum_year_dict.get(year, 0)
+        year_length = str(int(year_length)) + f" {self.poster.units}"
+        dr.add(
+            dr.text(
+                f"{year}" if _type is None else f"{_type}",
+                insert=offset.tuple(),
+                fill=self.poster.colors["text"],
+                alignment_baseline="hanging",
+                style=self.year_style,
             )
-            year_length = total_sum_year_dict.get(year, 0)
-            year_length = str(int(year_length)) + f" {self.poster.units}"
+        )
+
+        if not self.poster.is_multiple_type:
             dr.add(
                 dr.text(
-                    f"{year}",
-                    insert=offset.tuple(),
+                    f"{year_length}",
+                    insert=(offset.tuple()[0] + 165, offset.tuple()[1] + 5),
                     fill=self.poster.colors["text"],
                     alignment_baseline="hanging",
-                    style=year_style,
+                    style=self.year_length_style,
+                )
+            )
+        # add month name up to the poster one by one
+        # because of svg text auto trim the spaces.
+        for num, name in enumerate(MONTH_NAMES):
+            dr.add(
+                dr.text(
+                    f"{name}",
+                    insert=(offset.tuple()[0] + 15.5 * num, offset.tuple()[1] + 14),
+                    fill=self.poster.colors["text"],
+                    style=self.month_names_style,
                 )
             )
 
-            if not self.poster.is_multiple_type:
-                dr.add(
-                    dr.text(
-                        f"{year_length}",
-                        insert=(offset.tuple()[0] + 165, offset.tuple()[1] + 5),
-                        fill=self.poster.colors["text"],
-                        alignment_baseline="hanging",
-                        style=year_length_style,
-                    )
-                )
-            # add month name up to the poster one by one
-            # because of svg text auto trim the spaces.
-            for num, name in enumerate(MONTH_NAMES):
-                dr.add(
-                    dr.text(
-                        f"{name}",
-                        insert=(offset.tuple()[0] + 15.5 * num, offset.tuple()[1] + 14),
-                        fill=self.poster.colors["text"],
-                        style=month_names_style,
-                    )
+        rect_x = 10.0
+        animate_index = 1
+        year_count, key_times = 0, ""
+        if self.poster.with_animation:
+            # set default count 10
+            year_count = self.poster.year_tracks_date_count_dict.get(str(year), 10)
+            key_times = make_key_times(year_count)
+
+        # add every day of this year for 53 weeks and per week has 7 days
+        for _ in range(54):
+            rect_y = offset.y + self.year_size + 2
+            for _ in range(7):
+                if int(github_rect_day.year) > year:
+                    break
+                rect_y += 3.5
+                date_title = str(github_rect_day)
+                day_tracks = None
+                if date_title in self.poster.tracks:
+                    day_tracks = self.poster.tracks[date_title]
+
+                    # tricky for may cause animate error
+                    if animate_index < len(key_times) - 1:
+                        animate_index += 1
+                gen_box_func = (
+                    self._gen_day_box
+                    if len(self.poster.type_list) == 1
+                    else self._gen_day_boxes
                 )
+                for rect in gen_box_func(
+                    dr,
+                    rect_x,
+                    rect_y,
+                    date_title,
+                    day_tracks,
+                    self.poster.with_animation,
+                    key_times,
+                    animate_index,
+                ):
+                    dr.add(rect)
+                github_rect_day += datetime.timedelta(1)
+            rect_x += 3.5
+        offset.y += 3.5 * 9 + self.year_size + 1.5
 
-            rect_x = 10.0
-            animate_index = 1
-            year_count, key_times = 0, ""
-            if self.poster.with_animation:
-                # set default count 10
-                year_count = self.poster.year_tracks_date_count_dict.get(str(year), 10)
-                key_times = make_key_times(year_count)
+    def draw(self, dr, offset, is_summary=False):
+        if self.poster.tracks is None:
+            raise BaseDrawError("No tracks to draw")
 
-            # add every day of this year for 53 weeks and per week has 7 days
-            for _ in range(54):
-                rect_y = offset.y + year_size + 2
-                for _ in range(7):
-                    if int(github_rect_day.year) > year:
-                        break
-                    rect_y += 3.5
-                    date_title = str(github_rect_day)
-                    day_tracks = None
-                    if date_title in self.poster.tracks:
-                        day_tracks = self.poster.tracks[date_title]
-
-                        # tricky for may cause animate error
-                        if animate_index < len(key_times) - 1:
-                            animate_index += 1
-                    gen_box_func = (
-                        self._gen_day_box
-                        if len(self.poster.type_list) == 1
-                        else self._gen_day_boxes
-                    )
-                    for rect in gen_box_func(
-                        dr,
-                        rect_x,
-                        rect_y,
-                        date_title,
-                        day_tracks,
-                        self.poster.with_animation,
-                        key_times,
-                        animate_index,
-                    ):
-                        dr.add(rect)
-                    github_rect_day += datetime.timedelta(1)
-                rect_x += 3.5
-            offset.y += 3.5 * 9 + year_size + 1.5
+        if is_summary:
+            for l in self.poster.loader_list:
+                tracks, years = l.get_all_track_data()
+                self.poster.set_tracks(tracks, years, [])
+                self.poster.type_list = ["summary"]
+                self.poster.special_number = {
+                    "special_number1": l.special_number1,
+                    "special_number2": l.special_number2,
+                }
+                self.poster.colors["track"] = l.track_color or "#4DD2FF"
+                self.poster.units = l.unit
+                self.poster.compute_track_statistics([l._type])
+                self._draw_one_calendar(dr, years[0], offset, _type=l._type)
+        else:
+            for year in range(self.poster.years[0], self.poster.years[-1] + 1)[::-1]:
+                self._draw_one_calendar(dr, year, offset)
 
     def draw_footer(self, dr):
         text_color = self.poster.colors["text"]
-        header_style = f"font-size:4px; font-family:{self.poster.font}"
+        header_style = "font-size:4px; font-family:Arial"
         x = 10
         y = self.poster.height - 2.5
         index = 0
