@@ -4,7 +4,7 @@ from re import findall
 
 def parse_kindle_text_to_list(text):
     """
-    whole html file js -> [data1, data2, data3.........]
+    whole html file js -> [date1, date2, date3.........]
     """
     r = findall('"days_read":(.*),"goal_info"', text)
     if r:
